@@ -1,5 +1,5 @@
 package Form::Factory::Action;
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 use Moose::Role;
 
 use Carp ();
@@ -15,7 +15,7 @@ Form::Factory::Action - Role implemented by actions
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head2 SYNOPSIS
 
@@ -216,6 +216,7 @@ sub _build_controls {
             $control_args{control} => $control_args{options},
         );
 
+        my @init_control_features;
         for my $feature_name (keys %$meta_features) {
             my $feature_class = $feature_classes{$feature_name};
 
@@ -226,6 +227,13 @@ sub _build_controls {
             );
             push @$features, $feature;
             push @{ $control->features }, $feature;
+
+            push @init_control_features, $feature
+                if $feature->does('Form::Factory::Feature::Role::InitializeControl');
+        }
+
+        for my $feature (@init_control_features) {
+            $feature->initialize_control;
         }
 
         $controls{ $meta_control->name } = $control;
